@@ -1,24 +1,24 @@
 
 package Importer::Zim;
-$Importer::Zim::VERSION = '0.5.0';
+$Importer::Zim::VERSION = '0.6.0';
 # ABSTRACT: Import functions à la Invader Zim
 
 use 5.010001;
 use warnings;
-use Carp            ();
 use Module::Runtime ();
 
-use constant DEBUG => $ENV{IMPORTER_ZIM_DEBUG} || 0;
+use Importer::Zim::Utils 0.8.0 qw(DEBUG carp croak);
 
 sub import {
-    shift->backend(@_)->import(@_);
+    unshift @_, shift->backend(@_);
+    goto &{ $_[0]->can('import') };
 }
 
 my %MIN_VERSION = do {
     my %v = (
-        '+Lexical'    => '0.6.0',
-        '+EndOfScope' => '0.1.0',
-        '+Unit'       => '0.2.0'
+        '+Lexical'    => '0.8.0',
+        '+EndOfScope' => '0.2.0',
+        '+Unit'       => '0.3.0'
     );
     /^\+/ and $v{ backend_class($_) } = $v{$_} for keys %v;
     %v;
@@ -43,18 +43,18 @@ sub backend {
         _trace_backend( $mod, $backend, @version ) if DEBUG;
         return $mod if $mod;
     }
-    Carp::croak qq{Can't load no backend};
+    croak qq{Can't load any backend};
 }
 
 sub _trace_backend {
     my ( $mod, $backend, $version ) = @_;
     my $rv = $version ? " $version+" : '';
     unless ($mod) {
-        warn qq{Failed to load "$backend"$rv backend.\n};
+        carp qq{Failed to load "$backend"$rv backend};
         return;
     }
     my $v = $mod->VERSION // 'NA';
-    warn qq{Loaded "$backend"$rv ($v) backend.\n};
+    carp qq{Loaded "$backend"$rv ($v) backend};
 }
 
 1;
@@ -115,7 +115,7 @@ sub _trace_backend {
 #pod
 #pod =back
 #pod
-#pod Read also L<Importer::Zim::Cookbook/WHAT BACKEND?>.
+#pod Read also L<Importer::Zim::Cookbook/WHICH BACKEND?>.
 #pod
 #pod =head1 METHODS
 #pod
@@ -155,7 +155,7 @@ Importer::Zim - Import functions à la Invader Zim
 
 =head1 VERSION
 
-version 0.5.0
+version 0.6.0
 
 =head1 SYNOPSIS
 
@@ -211,7 +211,7 @@ while current unit is compiled
 
 =back
 
-Read also L<Importer::Zim::Cookbook/WHAT BACKEND?>.
+Read also L<Importer::Zim::Cookbook/WHICH BACKEND?>.
 
 =head1 METHODS
 
